<img src="Voicelab/favicon.ico">**VoiceLab**
======
**Automated Reproducible Acoustical Analysis**



## Contributors
David Feinberg, PhD  

Oliver Cook

## Version 
* Version 0.1

## Contact
#### feinberg@mcmaster.ca

Installation instructions:
We recommend setting up a new env in Anaconda with Python 3.7.
1. <code>conda create -n voicelab python=3.7 -y</code>
2. <code>conda activate voicelab</code>
3. <code>git clone git@github.com:Voice-Lab/VoiceLab.git</code>
4. <code>pip install .</code>
5. <code>python voicelab.py<code>
